@@ -3,8 +3,9 @@ use include_dir::{include_dir, Dir};
 use lazy_static::lazy_static;
 use sqlx::PgPool;
 use std::error::Error;
+pub mod schema;
 
-const DB_SCRIPTS: Dir = include_dir!("./scripts");
+const DB_SCRIPTS: Dir = include_dir!("$CARGO_MANIFEST_DIR/scripts");
 
 lazy_static! {
   static ref SQUIRREL: SchemaResolver = SchemaResolver::new(&DB_SCRIPTS);
